@@ -69,7 +69,7 @@ def filter_settings_by_register(obj,param):
         "img":"Scrapy_Prj.pipelines.ossimgpipelines.OssImagesPipeline",
         "img_bak":"Scrapy_Prj.pipelines.ossimgpipelines.OssImagesPipelineBak",
         "pyppeteer":"gerapy_pyppeteer.downloadermiddlewares.PyppeteerMiddleware",
-        "bloom":"scrapy.xcc_pipelines.bloomerfiler.BloomFilterPipeline",
+        "bloom":"Scrapy_Prj.pipelines.bloomerfiler.BloomFilterPipeline",
         "mysql":"Scrapy_Prj.pipelines.mysqlpipelines.MySQLPipeline",
         "mongo":"Scrapy_Prj.pipelines.mongodbPipelines.MongodbPipeline",
         "rabbit":"Scrapy_Prj.pipelines.rabbitmqpipelines.RabbitMQPipeline",
