@@ -138,10 +138,10 @@ class BloomFilterPipeline(object):
     def process_item(self, item, spider):
         postItem = dict(item)
         item_str = self.iter_dict_total(postItem)
+        msg = item.get("title", "") or item.get("category_name","") or item.get("url","") or item.get("sources","") # or item.get("")
         if self.isContains(item_str):  # 判断字符串是否存在
-            raise DropItem('This is item exists!')
+            DropItem(f'This is item exists! info: {msg}')
         else:
-            print('This is item not exists!')
             self.insert(item_str)
             return item
 
